    	Vitamin B:
    		https://en.wikipedia.org/wiki/B_vitamins

    		[ 'vitamin b1', 'thiamine' ]
    		[ 'vitamin b2', 'riboflavin' ]

    		[ 'vitamin b3' ]
    			[ 'niacin', 'nicotinamide', 'nicotinamide riboside' ]

    			Inputs that produce coenzymes called "NAD" and "NADP"
    			which are used for metabolic processes.

    		[ 'vitamin b5', 'panothenic acid' ]

    		[ 'vitamin b5', 'panothenic acid' ]